==> bplan-base-globals-1.1.0-0b4347.zip: lang/bg/global.php <==
<?php
/**
 *
 * @version     1.0.$Revision:$
 * @version     SVN: $Id:$
 * @package     bplan-base/globals
 * @subpackage  Locales
 * @author      Emilio Cannarozzo <emilio.cannarozzo@bplan-solutions.de>
 * @author      Wassilios Meletiadis <wassilios.meletiadis@bplan-solutions.de>
 * @copyright   Copyright (C) 2025 bplan-solutions GmbH & Co. KG <http://www.bplan-solutions.de/>
 * /Δ\
 */

return [

    'iso-3166-1-alpha-2' => 'bg',
    'language' => 'Български',
    'locale' => 'bg_BG',

    'currency.decimals'        => "2",
    'currency.format.string'   => ':value лв.',
    'currency.format.negative' => '-:value лв.',
    'currency.iso4217.alpha'   => 'BGN',
    'currency.iso4217.numeric' => 975,
    'currency.name'            => 'Български лев',
    'currency.subunit.divisor' => 100,
    'currency.subunit.name'    => 'Стотинка',
    'currency.subunit.symbol'  => 'ст.',
    'currency.symbol'          => 'лв.',

    'date.format'       => 'd.m.Y',
    'datetime.format'   => 'd.m.Y, H:i',
    'datetime.format+'  => 'd.m.Y, H:i:s',
    'datetime.format-+' => 'd.m.Y, H:i',
    'datetime.format++' => 'd.m.Y, H:i:s',
    'time.format'       => 'H:i',
    'time.format+'      => 'H:i:s',
    'time.format-+'     => 'H:i',
    'time.format++'     => 'H:i:s',

    'number.decimal-point'       => ',',
    'number.thousands-separator' => ' ',

    'text.direction'    => 'ltr',
    'text.orientation'  => 'sideways',
    'text.writing-mode' => 'vertical-rl',

    // -------------------------------------------------------------------

    'action.activate'      => 'Активиране',
    'action.add'           => 'Добавяне',
    'action.cancel'        => 'Отказ',
    'action.cancel-upload' => 'Отказ на качването',
    'action.change'        => 'Промяна',
    'action.close'         => 'Затваряне',
    'action.confirm'       => 'Потвърждение',
    'action.deactivate'    => 'Деактивиране',
    'action.delete'        => 'Изтриване',
    'action.edit'          => 'Редактиране',
    'action.import'        => 'Внасяне',
    'action.print'         => 'Печат',
    'action.save'          => 'Запазване',
    'action.search'        => 'Търсене',
    'action.sync'          => 'Синхронизиране',
    'action.upload'        => 'Качване на файл',
    'action.verify'        => 'Потвърждаване',
    'action.view'          => 'Преглед',

    'languages' => [
        'bg' => 'Български',
        'de' => 'Немски',
        'en' => 'Английски',
        'es' => 'Испански',
        'fr' => 'Френски',
        'hu' => 'Унгарски',
        'it' => 'Италиански',
        'lt' => 'Литовски',
        'pl' => 'Полски',
        'ro' => 'Румънски',
        'ru' => 'Руски',
        'tr' => 'Турски',
        'uk' => 'Украински',
    ],

    'option.yes' => 'Да',
    'option.no'  => 'Не',

    'required-hint'   => 'Маркираните полета (<span class="required-marker">:marker</span>) са задължителни',
    'required-marker' => '*',

    'select-option.please-select' => ' -- Моля, изберете -- ',

    'status.active'   => 'Активен',
    'status.expired'  => 'Изтекъл',
    'status.inactive' => 'Неактивен',
    'status.invalid'  => 'Невалиден',
    'status.loading'  => 'Зареждане...',
    'status.not-set'  => 'Не е зададено',
    'status.valid'    => 'Валиден',

];

==> bplan-base-globals-1.2.0-009337.zip: lang/bg/global.php <==
<?php
/**
 *
 * @version     1.0.$Revision:$
 * @version     SVN: $Id:$
 * @package     bplan-base/globals
 * @subpackage  Locales
 * @author      Emilio Cannarozzo <emilio.cannarozzo@bplan-solutions.de>
 * @author      Wassilios Meletiadis <wassilios.meletiadis@bplan-solutions.de>
 * @copyright   Copyright (C) 2025 bplan-solutions GmbH & Co. KG <http://www.bplan-solutions.de/>
 * /Δ\
 */

return [

    'iso-3166-1-alpha-2' => 'bg',
    'language' => 'Български',
    'locale' => 'bg_BG',

    'currency.decimals'        => "2",
    'currency.format.string'   => ':value лв.',
    'currency.format.negative' => '-:value лв.',
    'currency.iso4217.alpha'   => 'BGN',
    'currency.iso4217.numeric' => 975,
    'currency.name'            => 'Български лев',
    'currency.subunit.divisor' => 100,
    'currency.subunit.name'    => 'Стотинка',
    'currency.subunit.symbol'  => 'ст.',
    'currency.symbol'          => 'лв.',

    'date.format'       => 'd.m.Y',
    'datetime.format'   => 'd.m.Y, H:i',
    'datetime.format+'  => 'd.m.Y, H:i:s',
    'datetime.format-+' => 'd.m.Y, H:i',
    'datetime.format++' => 'd.m.Y, H:i:s',
    'time.format'       => 'H:i',
    'time.format+'      => 'H:i:s',
    'time.format-+'     => 'H:i',
    'time.format++'     => 'H:i:s',

    'number.decimal-point'       => ',',
    'number.thousands-separator' => ' ',

    'text.direction'    => 'ltr',
    'text.orientation'  => 'sideways',
    'text.writing-mode' => 'vertical-rl',

    // -------------------------------------------------------------------

    'action.activate'      => 'Активиране',
    'action.add'           => 'Добавяне',
    'action.cancel'        => 'Отказ',
    'action.cancel-upload' => 'Отказ на качването',
    'action.change'        => 'Промяна',
    'action.close'         => 'Затваряне',
    'action.confirm'       => 'Потвърждение',
    'action.deactivate'    => 'Деактивиране',
    'action.delete'        => 'Изтриване',
    'action.edit'          => 'Редактиране',
    'action.import'        => 'Внасяне',
    'action.print'         => 'Печат',
    'action.save'          => 'Запазване',
    'action.search'        => 'Търсене',
    'action.sync'          => 'Синхронизиране',
    'action.upload'        => 'Качване на файл',
    'action.verify'        => 'Потвърждаване',
    'action.view'          => 'Преглед',

    'languages' => [
        'bg' => 'Български',
        'de' => 'Немски',
        'en' => 'Английски',
        'es' => 'Испански',
        'fr' => 'Френски',
        'hu' => 'Унгарски',
        'it' => 'Италиански',
        'lt' => 'Литовски',
        'pl' => 'Полски',
        'ro' => 'Румънски',
        'ru' => 'Руски',
        'tr' => 'Турски',
        'uk' => 'Украински',
    ],

    'option.yes' => 'Да',
    'option.no'  => 'Не',

    'required-hint'   => 'Маркираните полета (<span class="required-marker">:marker</span>) са задължителни',
    'required-marker' => '*',

    'select-option.no-options-available' => 'Няма налични опции',
    'select-option.please-select'        => ' -- Моля, изберете -- ',

    'status.active'   => 'Активен',
    'status.expired'  => 'Изтекъл',
    'status.inactive' => 'Неактивен',
    'status.invalid'  => 'Невалиден',
    'status.loading'  => 'Зареждане...',
    'status.not-set'  => 'Не е зададено',
    'status.valid'    => 'Валиден',

];
